From 9b6476c0a13f1666bc030f03afa4f49ad43a14e1 Mon Sep 17 00:00:00 2001 From: Rossen Stoyanchev Date: Mon, 31 Aug 2020 21:13:54 +0100 Subject: [PATCH] Rename MockMvcTestClient to MockMvcWebTestClient Closes gh-19647 --- .../web/reactive/server/ExchangeResult.java | 2 +- .../client/AbstractMockMvcServerSpec.java | 6 ++-- ...tClient.java => MockMvcWebTestClient.java} | 8 +++--- .../servlet/client/StandaloneMockMvcSpec.java | 6 ++-- .../AsyncControllerJavaConfigTests.java | 6 ++-- .../client/context/JavaConfigTests.java | 6 ++-- .../client/context/WebAppResourceTests.java | 8 +++--- .../client/context/XmlConfigTests.java | 6 ++-- .../samples/client/standalone/AsyncTests.java | 6 ++-- .../standalone/ExceptionHandlerTests.java | 18 ++++++------ .../client/standalone/FilterTests.java | 24 ++++++++-------- .../standalone/FrameworkExtensionTests.java | 6 ++-- .../standalone/MultipartControllerTests.java | 28 +++++++++---------- .../standalone/ReactiveReturnTypeTests.java | 6 ++-- .../client/standalone/RedirectTests.java | 18 ++++++------ .../standalone/RequestParameterTests.java | 6 ++-- .../client/standalone/ResponseBodyTests.java | 4 +-- .../standalone/ViewResolutionTests.java | 20 ++++++------- .../PrintingResultHandlerSmokeTests.java | 6 ++-- .../resultmatches/ContentAssertionTests.java | 6 ++-- .../resultmatches/CookieAssertionTests.java | 6 ++-- .../FlashAttributeAssertionTests.java | 8 +++--- .../resultmatches/HandlerAssertionTests.java | 8 +++--- .../resultmatches/HeaderAssertionTests.java | 6 ++-- .../resultmatches/JsonPathAssertionTests.java | 6 ++-- .../resultmatches/ModelAssertionTests.java | 8 +++--- .../RequestAttributeAssertionTests.java | 10 +++---- .../SessionAttributeAssertionTests.java | 8 +++--- .../resultmatches/StatusAssertionTests.java | 6 ++-- .../resultmatches/UrlAssertionTests.java | 10 +++---- .../resultmatches/ViewNameAssertionTests.java | 10 +++---- .../XmlContentAssertionTests.java | 6 ++-- .../resultmatches/XpathAssertionTests.java | 8 +++--- 33 files changed, 148 insertions(+), 148 deletions(-) rename spring-test/src/main/java/org/springframework/test/web/servlet/client/{MockMvcTestClient.java => MockMvcWebTestClient.java} (98%) diff --git a/spring-test/src/main/java/org/springframework/test/web/reactive/server/ExchangeResult.java b/spring-test/src/main/java/org/springframework/test/web/reactive/server/ExchangeResult.java index ff1c20d502..e4ee98e8a0 100644 --- a/spring-test/src/main/java/org/springframework/test/web/reactive/server/ExchangeResult.java +++ b/spring-test/src/main/java/org/springframework/test/web/reactive/server/ExchangeResult.java @@ -206,7 +206,7 @@ public class ExchangeResult { * Return the result from the mock server exchange, if applicable, for * further assertions on the state of the server response. * @since 5.3 - * @see org.springframework.test.web.servlet.client.MockMvcTestClient#resultActionsFor(ExchangeResult) + * @see org.springframework.test.web.servlet.client.MockMvcWebTestClient#resultActionsFor(ExchangeResult) */ @Nullable public Object getMockServerResult() { diff --git a/spring-test/src/main/java/org/springframework/test/web/servlet/client/AbstractMockMvcServerSpec.java b/spring-test/src/main/java/org/springframework/test/web/servlet/client/AbstractMockMvcServerSpec.java index 0e8dd4c2aa..cf1b2d60fe 100644 --- a/spring-test/src/main/java/org/springframework/test/web/servlet/client/AbstractMockMvcServerSpec.java +++ b/spring-test/src/main/java/org/springframework/test/web/servlet/client/AbstractMockMvcServerSpec.java @@ -27,7 +27,7 @@ import org.springframework.test.web.servlet.setup.ConfigurableMockMvcBuilder; import org.springframework.test.web.servlet.setup.MockMvcConfigurer; /** - * Base class for implementations of {@link MockMvcTestClient.MockMvcServerSpec} + * Base class for implementations of {@link MockMvcWebTestClient.MockMvcServerSpec} * that simply delegates to a {@link ConfigurableMockMvcBuilder} supplied by * the concrete sub-classes. * @@ -35,8 +35,8 @@ import org.springframework.test.web.servlet.setup.MockMvcConfigurer; * @since 5.3 * @param the type of the concrete sub-class spec */ -abstract class AbstractMockMvcServerSpec> - implements MockMvcTestClient.MockMvcServerSpec { +abstract class AbstractMockMvcServerSpec> + implements MockMvcWebTestClient.MockMvcServerSpec { @Override public T filters(Filter... filters) { diff --git a/spring-test/src/main/java/org/springframework/test/web/servlet/client/MockMvcTestClient.java b/spring-test/src/main/java/org/springframework/test/web/servlet/client/MockMvcWebTestClient.java similarity index 98% rename from spring-test/src/main/java/org/springframework/test/web/servlet/client/MockMvcTestClient.java rename to spring-test/src/main/java/org/springframework/test/web/servlet/client/MockMvcWebTestClient.java index 8e481389e5..a59879f795 100644 --- a/spring-test/src/main/java/org/springframework/test/web/servlet/client/MockMvcTestClient.java +++ b/spring-test/src/main/java/org/springframework/test/web/servlet/client/MockMvcWebTestClient.java @@ -57,7 +57,7 @@ import org.springframework.web.util.pattern.PathPatternParser; *

Provides static factory methods and specs to initialize {@code MockMvc} * to which the {@code WebTestClient} connects to. For example: *

- * WebTestClient client = MockMvcTestClient.bindToController(myController)
+ * WebTestClient client = MockMvcWebTestClient.bindToController(myController)
  *         .controllerAdvice(myControllerAdvice)
  *         .validator(myValidator)
  *         .build()
@@ -65,7 +65,7 @@ import org.springframework.web.util.pattern.PathPatternParser;
  *
  * 

The client itself can also be configured. For example: *

- * WebTestClient client = MockMvcTestClient.bindToController(myController)
+ * WebTestClient client = MockMvcWebTestClient.bindToController(myController)
  *         .validator(myValidator)
  *         .configureClient()
  *         .baseUrl("/path")
@@ -75,7 +75,7 @@ import org.springframework.web.util.pattern.PathPatternParser;
  * @author Rossen Stoyanchev
  * @since 5.3
  */
-public interface MockMvcTestClient {
+public interface MockMvcWebTestClient {
 
 	/**
 	 * Begin creating a {@link WebTestClient} by providing the {@code @Controller}
@@ -128,7 +128,7 @@ public interface MockMvcTestClient {
 	 * 				.expectHeader().location("/persons/Joe")
 	 * 				.expectBody().isEmpty();
 	 *
-	 * MockMvcTestClient.resultActionsFor(result)
+	 * MockMvcWebTestClient.resultActionsFor(result)
 	 * 		.andExpect(model().size(1))
 	 * 		.andExpect(model().attributeExists("name"))
 	 * 		.andExpect(flash().attributeCount(1))
diff --git a/spring-test/src/main/java/org/springframework/test/web/servlet/client/StandaloneMockMvcSpec.java b/spring-test/src/main/java/org/springframework/test/web/servlet/client/StandaloneMockMvcSpec.java
index 4226402768..63cdee1d5d 100644
--- a/spring-test/src/main/java/org/springframework/test/web/servlet/client/StandaloneMockMvcSpec.java
+++ b/spring-test/src/main/java/org/springframework/test/web/servlet/client/StandaloneMockMvcSpec.java
@@ -38,13 +38,13 @@ import org.springframework.web.util.pattern.PathPatternParser;
 
 /**
  * Simple wrapper around a {@link StandaloneMockMvcBuilder} that implements
- * {@link MockMvcTestClient.ControllerSpec}.
+ * {@link MockMvcWebTestClient.ControllerSpec}.
  *
  * @author Rossen Stoyanchev
  * @since 5.3
  */
-class StandaloneMockMvcSpec extends AbstractMockMvcServerSpec
-		implements MockMvcTestClient.ControllerSpec {
+class StandaloneMockMvcSpec extends AbstractMockMvcServerSpec
+		implements MockMvcWebTestClient.ControllerSpec {
 
 	private final StandaloneMockMvcBuilder mockMvcBuilder;
 
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ResponseBodyTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ResponseBodyTests.java
index 2034d3c8de..d441e8d0aa 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ResponseBodyTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ResponseBodyTests.java
@@ -20,7 +20,7 @@ import javax.validation.constraints.NotNull;
 import org.junit.jupiter.api.Test;
 
 import org.springframework.http.MediaType;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.GetMapping;
 import org.springframework.web.bind.annotation.PathVariable;
 import org.springframework.web.bind.annotation.RestController;
@@ -37,7 +37,7 @@ public class ResponseBodyTests {
 
 	@Test
 	void json() {
-		MockMvcTestClient.bindToController(new PersonController()).build()
+		MockMvcWebTestClient.bindToController(new PersonController()).build()
 				.get()
 				.uri("/person/Lee")
 				.accept(MediaType.APPLICATION_JSON)
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/AsyncControllerJavaConfigTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/AsyncControllerJavaConfigTests.java
index 1908958a63..9dfdd3effc 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/AsyncControllerJavaConfigTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/AsyncControllerJavaConfigTests.java
@@ -34,7 +34,7 @@ import org.springframework.test.context.ContextHierarchy;
 import org.springframework.test.context.junit.jupiter.SpringExtension;
 import org.springframework.test.context.web.WebAppConfiguration;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.GetMapping;
 import org.springframework.web.bind.annotation.RestController;
 import org.springframework.web.context.WebApplicationContext;
@@ -46,7 +46,7 @@ import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;
 import static org.mockito.ArgumentMatchers.any;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.context.AsyncControllerJavaConfigTests}.
  *
  * @author Rossen Stoyanchev
@@ -67,7 +67,7 @@ public class AsyncControllerJavaConfigTests {
 
 	@BeforeEach
 	public void setup() {
-		this.testClient = MockMvcTestClient.bindToApplicationContext(this.wac).build();
+		this.testClient = MockMvcWebTestClient.bindToApplicationContext(this.wac).build();
 	}
 
 	@Test
@@ -46,7 +46,7 @@ import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.context.AsyncControllerJavaConfigTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/JavaConfigTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/JavaConfigTests.java
index 5ddd1859ad..f8b02550ec 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/JavaConfigTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/JavaConfigTests.java
@@ -31,7 +31,7 @@ import org.springframework.test.context.junit.jupiter.SpringExtension;
 import org.springframework.test.context.web.WebAppConfiguration;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.test.web.servlet.samples.context.PersonController;
 import org.springframework.test.web.servlet.samples.context.PersonDao;
 import org.springframework.web.context.WebApplicationContext;
@@ -46,7 +46,7 @@ import org.springframework.web.servlet.view.tiles3.TilesConfigurer;
 import static org.mockito.BDDMockito.given;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.context.JavaConfigTests}.
  *
  * @author Rossen Stoyanchev
@@ -73,7 +73,7 @@ public class JavaConfigTests {
 
 	@BeforeEach
 	public void setup() {
-		this.testClient = MockMvcTestClient.bindToApplicationContext(this.wac).build();
+		this.testClient = MockMvcWebTestClient.bindToApplicationContext(this.wac).build();
 		given(this.personDao.getPerson(5L)).willReturn(new Person("Joe"));
 	}
 
@@ -46,7 +46,7 @@ import org.springframework.web.servlet.view.tiles3.TilesConfigurer;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.context.JavaConfigTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/WebAppResourceTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/WebAppResourceTests.java
index 93457f87fd..ec356ba072 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/WebAppResourceTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/WebAppResourceTests.java
@@ -27,7 +27,7 @@ import org.springframework.test.context.junit.jupiter.SpringExtension;
 import org.springframework.test.context.web.WebAppConfiguration;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.context.WebApplicationContext;
 import org.springframework.web.servlet.resource.DefaultServletHttpRequestHandler;
 
@@ -36,7 +36,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.handler;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.context.WebAppResourceTests}.
  *
  * @author Rossen Stoyanchev
@@ -57,7 +57,7 @@ public class WebAppResourceTests {
 
 	@BeforeEach
 	public void setup() {
-		this.testClient = MockMvcTestClient.bindToApplicationContext(this.wac).build();
+		this.testClient = MockMvcWebTestClient.bindToApplicationContext(this.wac).build();
 	}
 
 	// TilesConfigurer: resources under "/WEB-INF/**/tiles.xml"
@@ -90,7 +90,7 @@ public class WebAppResourceTests {
 				.expectStatus().isOk()
 				.expectBody().isEmpty();
 
-		MockMvcTestClient.resultActionsFor(result)
+		MockMvcWebTestClient.resultActionsFor(result)
 				.andExpect(handler().handlerType(DefaultServletHttpRequestHandler.class))
 				.andExpect(forwardedUrl("default"));
 	}
@@ -36,7 +36,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.context.WebAppResourceTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/XmlConfigTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/XmlConfigTests.java
index 79ca42bf84..f3364da579 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/XmlConfigTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/context/XmlConfigTests.java
@@ -28,14 +28,14 @@ import org.springframework.test.context.junit.jupiter.SpringExtension;
 import org.springframework.test.context.web.WebAppConfiguration;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.test.web.servlet.samples.context.PersonDao;
 import org.springframework.web.context.WebApplicationContext;
 
 import static org.mockito.BDDMockito.given;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.context.XmlConfigTests}.
  *
  * @author Rossen Stoyanchev
@@ -59,7 +59,7 @@ public class XmlConfigTests {
 
 	@BeforeEach
 	public void setup() {
-		this.testClient = MockMvcTestClient.bindToApplicationContext(this.wac).build();
+		this.testClient = MockMvcWebTestClient.bindToApplicationContext(this.wac).build();
 		given(this.personDao.getPerson(5L)).willReturn(new Person("Joe"));
 	}
 
@@ -28,14 +28,14 @@ import org.springframework.test.context.junit.jupiter.SpringExtension;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.context.XmlConfigTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/AsyncTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/AsyncTests.java
index 707602bfeb..fa118ffabd 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/AsyncTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/AsyncTests.java
@@ -28,7 +28,7 @@ import org.springframework.http.MediaType;
 import org.springframework.http.ResponseEntity;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.util.concurrent.ListenableFuture;
 import org.springframework.util.concurrent.ListenableFutureTask;
 import org.springframework.web.bind.annotation.ExceptionHandler;
@@ -39,7 +39,7 @@ import org.springframework.web.context.request.async.DeferredResult;
 import org.springframework.web.servlet.mvc.method.annotation.StreamingResponseBody;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.AsyncTests}.
  *
  * @author Rossen Stoyanchev
@@ -47,7 +47,7 @@ import org.springframework.web.servlet.mvc.method.annotation.StreamingResponseBo
 public class AsyncTests {
 
 	private final WebTestClient testClient =
-			MockMvcTestClient.bindToController(new AsyncController()).build();
+			MockMvcWebTestClient.bindToController(new AsyncController()).build();
 
 
 	@Test
@@ -39,7 +39,7 @@ import org.springframework.web.context.request.async.DeferredResult;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.AsyncTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ExceptionHandlerTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ExceptionHandlerTests.java
index 6dce2699cc..75c8041464 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ExceptionHandlerTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ExceptionHandlerTests.java
@@ -24,7 +24,7 @@ import org.springframework.core.annotation.Order;
 import org.springframework.http.MediaType;
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.ControllerAdvice;
 import org.springframework.web.bind.annotation.ExceptionHandler;
 import org.springframework.web.bind.annotation.GetMapping;
@@ -33,7 +33,7 @@ import org.springframework.web.bind.annotation.RestController;
 import org.springframework.web.bind.annotation.RestControllerAdvice;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.ExceptionHandlerTests}.
  *
  * @author Rossen Stoyanchev
@@ -45,7 +45,7 @@ class ExceptionHandlerTests {
 
 		@Test
 		void localExceptionHandlerMethod() {
-			WebTestClient client = MockMvcTestClient.bindToController(new PersonController()).build();
+			WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController()).build();
 
 			client.get().uri("/person/Clyde")
 					.exchange()
@@ -55,7 +55,7 @@ class ExceptionHandlerTests {
 
 		@Test
 		void globalExceptionHandlerMethod() {
-			WebTestClient client = MockMvcTestClient.bindToController(new PersonController())
+			WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController())
 					.controllerAdvice(new GlobalExceptionHandler())
 					.build();
 
@@ -102,7 +102,7 @@ class ExceptionHandlerTests {
 
 		@Test
 		void noException() {
-			WebTestClient client = MockMvcTestClient.bindToController(new RestPersonController())
+			WebTestClient client = MockMvcWebTestClient.bindToController(new RestPersonController())
 					.controllerAdvice(new RestPersonControllerExceptionHandler())
 					.build();
 
@@ -115,7 +115,7 @@ class ExceptionHandlerTests {
 
 		@Test
 		void localExceptionHandlerMethod() {
-			WebTestClient client = MockMvcTestClient.bindToController(new RestPersonController())
+			WebTestClient client = MockMvcWebTestClient.bindToController(new RestPersonController())
 					.controllerAdvice(new RestPersonControllerExceptionHandler())
 					.build();
 
@@ -128,7 +128,7 @@ class ExceptionHandlerTests {
 
 		@Test
 		void globalExceptionHandlerMethod() {
-			WebTestClient client = MockMvcTestClient.bindToController(new RestPersonController())
+			WebTestClient client = MockMvcWebTestClient.bindToController(new RestPersonController())
 					.controllerAdvice(new RestGlobalExceptionHandler())
 					.build();
 
@@ -141,7 +141,7 @@ class ExceptionHandlerTests {
 
 		@Test
 		void globalRestPersonControllerExceptionHandlerTakesPrecedenceOverGlobalExceptionHandler() {
-			WebTestClient client = MockMvcTestClient.bindToController(new RestPersonController())
+			WebTestClient client = MockMvcWebTestClient.bindToController(new RestPersonController())
 					.controllerAdvice(RestGlobalExceptionHandler.class, RestPersonControllerExceptionHandler.class)
 					.build();
 
@@ -154,7 +154,7 @@ class ExceptionHandlerTests {
 
 		@Test
 		void noHandlerFound() {
-			WebTestClient client = MockMvcTestClient.bindToController(new RestPersonController())
+			WebTestClient client = MockMvcWebTestClient.bindToController(new RestPersonController())
 					.controllerAdvice(RestGlobalExceptionHandler.class, RestPersonControllerExceptionHandler.class)
 					.dispatcherServletCustomizer(servlet -> servlet.setThrowExceptionIfNoHandlerFound(true))
 					.build();
@@ -33,7 +33,7 @@ import org.springframework.web.bind.annotation.RestController;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.ExceptionHandlerTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/FilterTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/FilterTests.java
index ea5b3a1205..3016c00d79 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/FilterTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/FilterTests.java
@@ -40,7 +40,7 @@ import org.springframework.stereotype.Controller;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.validation.Errors;
 import org.springframework.web.bind.annotation.GetMapping;
 import org.springframework.web.bind.annotation.PostMapping;
@@ -54,7 +54,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.model;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.FilterTests}.
  *
  * @author Rossen Stoyanchev
@@ -63,7 +63,7 @@ public class FilterTests {
 
 	@Test
 	public void whenFiltersCompleteMvcProcessesRequest() throws Exception {
-		WebTestClient client = MockMvcTestClient.bindToController(new PersonController())
+		WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController())
 				.filters(new ContinueFilter())
 				.build();
 
@@ -74,7 +74,7 @@ public class FilterTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().size(1))
 				.andExpect(model().attributeExists("id"))
 				.andExpect(flash().attributeCount(1))
@@ -83,7 +83,7 @@ public class FilterTests {
 
 	@Test
 	public void filtersProcessRequest() {
-		WebTestClient client = MockMvcTestClient.bindToController(new PersonController())
+		WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController())
 				.filters(new ContinueFilter(), new RedirectFilter())
 				.build();
 
@@ -95,7 +95,7 @@ public class FilterTests {
 
 	@Test
 	public void filterMappedBySuffix() {
-		WebTestClient client = MockMvcTestClient.bindToController(new PersonController())
+		WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController())
 				.filter(new RedirectFilter(), "*.html")
 				.build();
 
@@ -107,7 +107,7 @@ public class FilterTests {
 
 	@Test
 	public void filterWithExactMapping() {
-		WebTestClient client = MockMvcTestClient.bindToController(new PersonController())
+		WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController())
 				.filter(new RedirectFilter(), "/p", "/persons")
 				.build();
 
@@ -119,7 +119,7 @@ public class FilterTests {
 
 	@Test
 	public void filterSkipped() throws Exception {
-		WebTestClient client = MockMvcTestClient.bindToController(new PersonController())
+		WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController())
 				.filter(new RedirectFilter(), "/p", "/person")
 				.build();
 
@@ -131,7 +131,7 @@ public class FilterTests {
 						.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().size(1))
 				.andExpect(model().attributeExists("id"))
 				.andExpect(flash().attributeCount(1))
@@ -140,7 +140,7 @@ public class FilterTests {
 
 	@Test
 	public void filterWrapsRequestResponse() throws Exception {
-		WebTestClient client = MockMvcTestClient.bindToController(new PersonController())
+		WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController())
 				.filter(new WrappingRequestResponseFilter())
 				.build();
 
@@ -148,13 +148,13 @@ public class FilterTests {
 				client.post().uri("/user").exchange().expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attribute("principal", WrappingRequestResponseFilter.PRINCIPAL_NAME));
 	}
 
 	@Test
 	public void filterWrapsRequestResponseAndPerformsAsyncDispatch() {
-		WebTestClient client = MockMvcTestClient.bindToController(new PersonController())
+		WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController())
 				.filters(new WrappingRequestResponseFilter(), new ShallowEtagHeaderFilter())
 				.build();
 
@@ -54,7 +54,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.FilterTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/FrameworkExtensionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/FrameworkExtensionTests.java
index 71dc559237..feabca799f 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/FrameworkExtensionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/FrameworkExtensionTests.java
@@ -22,7 +22,7 @@ import org.junit.jupiter.api.Test;
 
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.test.web.servlet.request.RequestPostProcessor;
 import org.springframework.test.web.servlet.setup.ConfigurableMockMvcBuilder;
 import org.springframework.test.web.servlet.setup.MockMvcConfigurerAdapter;
@@ -35,7 +35,7 @@ import static org.mockito.Mockito.mock;
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.FrameworkExtensionTests}.
  *
  * @author Rossen Stoyanchev
@@ -43,7 +43,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 public class FrameworkExtensionTests {
 
 	private final WebTestClient client =
-			MockMvcTestClient.bindToController(new SampleController())
+			MockMvcWebTestClient.bindToController(new SampleController())
 					.apply(defaultSetup())
 					.build();
 
@@ -35,7 +35,7 @@ import static org.mockito.Mockito.mock;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.FrameworkExtensionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/MultipartControllerTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/MultipartControllerTests.java
index a2dbc15dfe..b60a0e6f6e 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/MultipartControllerTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/MultipartControllerTests.java
@@ -37,7 +37,7 @@ import org.springframework.http.client.MultipartBodyBuilder;
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.ui.Model;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.bind.annotation.RequestMethod;
@@ -50,14 +50,14 @@ import static org.assertj.core.api.Assertions.assertThat;
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.model;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.MultipartControllerTests}.
  *
  * @author Rossen Stoyanchev
  */
 public class MultipartControllerTests {
 
-	private final WebTestClient testClient = MockMvcTestClient.bindToController(new MultipartController()).build();
+	private final WebTestClient testClient = MockMvcWebTestClient.bindToController(new MultipartController()).build();
 
 
 	@Test
@@ -77,7 +77,7 @@ public class MultipartControllerTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attribute("fileContent", fileContent))
 				.andExpect(model().attribute("jsonContent", json));
 	}
@@ -106,7 +106,7 @@ public class MultipartControllerTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attribute("fileContent", fileContent))
 				.andExpect(model().attribute("jsonContent", json));
 	}
@@ -134,7 +134,7 @@ public class MultipartControllerTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attribute("fileContent", fileContent))
 				.andExpect(model().attribute("jsonContent", json));
 	}
@@ -153,7 +153,7 @@ public class MultipartControllerTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attributeDoesNotExist("fileContent"))
 				.andExpect(model().attribute("jsonContent", json));
 	}
@@ -175,7 +175,7 @@ public class MultipartControllerTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attribute("fileContent", fileContent))
 				.andExpect(model().attribute("jsonContent", json));
 	}
@@ -194,7 +194,7 @@ public class MultipartControllerTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attributeDoesNotExist("fileContent"))
 				.andExpect(model().attribute("jsonContent", json));
 	}
@@ -216,7 +216,7 @@ public class MultipartControllerTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attribute("fileContent", fileContent))
 				.andExpect(model().attribute("jsonContent", json));
 	}
@@ -235,7 +235,7 @@ public class MultipartControllerTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attributeDoesNotExist("fileContent"))
 				.andExpect(model().attribute("jsonContent", json));
 	}
@@ -256,7 +256,7 @@ public class MultipartControllerTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attribute("fileContent", fileContent))
 				.andExpect(model().attribute("jsonContent", json));
 	}
@@ -268,7 +268,7 @@ public class MultipartControllerTests {
 		MultipartBodyBuilder bodyBuilder = new MultipartBodyBuilder();
 		bodyBuilder.part("json", json, MediaType.APPLICATION_JSON);
 
-		WebTestClient client = MockMvcTestClient.bindToController(new MultipartController())
+		WebTestClient client = MockMvcWebTestClient.bindToController(new MultipartController())
 				.filter(new RequestWrappingFilter())
 				.build();
 
@@ -279,7 +279,7 @@ public class MultipartControllerTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().attribute("jsonContent", json));
 	}
 
@@ -50,14 +50,14 @@ import static org.assertj.core.api.Assertions.assertThat;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.MultipartControllerTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ReactiveReturnTypeTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ReactiveReturnTypeTests.java
index bf6549fd26..9229ef6839 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ReactiveReturnTypeTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ReactiveReturnTypeTests.java
@@ -23,14 +23,14 @@ import reactor.test.StepVerifier;
 
 import org.springframework.http.MediaType;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.GetMapping;
 import org.springframework.web.bind.annotation.RestController;
 
 import static org.springframework.http.MediaType.TEXT_EVENT_STREAM;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.ReactiveReturnTypeTests}.
  *
  * @author Rossen Stoyanchev
@@ -41,7 +41,7 @@ public class ReactiveReturnTypeTests {
 	public void sseWithFlux() {
 
 		WebTestClient testClient =
-				MockMvcTestClient.bindToController(new ReactiveController()).build();
+				MockMvcWebTestClient.bindToController(new ReactiveController()).build();
 
 		Flux bodyFlux = testClient.get().uri("/spr16869")
 				.exchange()
@@ -23,14 +23,14 @@ import reactor.test.StepVerifier;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.ReactiveReturnTypeTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/RedirectTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/RedirectTests.java
index 2e8c1981a8..18c48affbc 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/RedirectTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/RedirectTests.java
@@ -24,7 +24,7 @@ import org.springframework.stereotype.Controller;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.test.web.servlet.result.MockMvcResultHandlers;
 import org.springframework.ui.Model;
 import org.springframework.validation.Errors;
@@ -39,7 +39,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.model;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.RedirectTests}.
  *
  * @author Rossen Stoyanchev
@@ -47,7 +47,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 public class RedirectTests {
 
 	private final WebTestClient testClient =
-			MockMvcTestClient.bindToController(new PersonController()).build();
+			MockMvcWebTestClient.bindToController(new PersonController()).build();
 
 
 	@Test
@@ -60,7 +60,7 @@ public class RedirectTests {
 						.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(exchangeResult)
+		MockMvcWebTestClient.resultActionsFor(exchangeResult)
 				.andExpect(model().size(1))
 				.andExpect(model().attributeExists("name"))
 				.andExpect(flash().attributeCount(1))
@@ -77,7 +77,7 @@ public class RedirectTests {
 						.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(result)
+		MockMvcWebTestClient.resultActionsFor(result)
 				.andExpect(model().size(1))
 				.andExpect(model().attributeExists("name"))
 				.andExpect(flash().attributeCount(1))
@@ -89,7 +89,7 @@ public class RedirectTests {
 		EntityExchangeResult result =
 				testClient.post().uri("/persons").exchange().expectStatus().isOk().expectBody().isEmpty();
 
-		MockMvcTestClient.resultActionsFor(result)
+		MockMvcWebTestClient.resultActionsFor(result)
 				.andExpect(forwardedUrl("persons/add"))
 				.andExpect(model().size(1))
 				.andExpect(model().attributeExists("person"))
@@ -101,7 +101,7 @@ public class RedirectTests {
 		EntityExchangeResult result =
 				testClient.post().uri("/people").exchange().expectStatus().isOk().expectBody().isEmpty();
 
-		MockMvcTestClient.resultActionsFor(result)
+		MockMvcWebTestClient.resultActionsFor(result)
 				.andExpect(forwardedUrl("persons/add"))
 				.andExpect(model().size(1))
 				.andExpect(model().attributeExists("person"))
@@ -111,7 +111,7 @@ public class RedirectTests {
 	@Test
 	public void getPerson() throws Exception {
 		EntityExchangeResult result =
-				MockMvcTestClient.bindToController(new PersonController())
+				MockMvcWebTestClient.bindToController(new PersonController())
 						.defaultRequest(get("/").flashAttr("message", "success!"))
 						.build()
 						.get().uri("/persons/Joe")
@@ -120,7 +120,7 @@ public class RedirectTests {
 						.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(result)
+		MockMvcWebTestClient.resultActionsFor(result)
 				.andDo(MockMvcResultHandlers.print())
 				.andExpect(forwardedUrl("persons/index"))
 				.andExpect(model().size(2))
@@ -39,7 +39,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.RedirectTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/RequestParameterTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/RequestParameterTests.java
index fb706063ea..d21e283e01 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/RequestParameterTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/RequestParameterTests.java
@@ -21,13 +21,13 @@ import org.springframework.http.MediaType;
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.bind.annotation.RequestParam;
 import org.springframework.web.bind.annotation.ResponseBody;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.RequestParameterTests}.
  *
  * @author Rossen Stoyanchev
@@ -37,7 +37,7 @@ public class RequestParameterTests {
 	@Test
 	public void queryParameter() {
 
-		WebTestClient client = MockMvcTestClient.bindToController(new PersonController()).build();
+		WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController()).build();
 
 		client.get().uri("/search?name=George")
 				.accept(MediaType.APPLICATION_JSON)
@@ -21,13 +21,13 @@ import org.springframework.http.MediaType;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.RequestParameterTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ViewResolutionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ViewResolutionTests.java
index 91fa05eb5f..d1d06aa97d 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ViewResolutionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/ViewResolutionTests.java
@@ -27,7 +27,7 @@ import org.springframework.stereotype.Controller;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.ui.Model;
 import org.springframework.web.accept.ContentNegotiationManager;
 import org.springframework.web.accept.FixedContentNegotiationStrategy;
@@ -47,7 +47,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.RequestParameterTests}.
  *
  * @author Rossen Stoyanchev
@@ -57,7 +57,7 @@ class ViewResolutionTests {
 	@Test
 	void jspOnly() throws Exception {
 		WebTestClient testClient =
-				MockMvcTestClient.bindToController(new PersonController())
+				MockMvcWebTestClient.bindToController(new PersonController())
 						.viewResolvers(new InternalResourceViewResolver("/WEB-INF/", ".jsp"))
 						.build();
 
@@ -67,7 +67,7 @@ class ViewResolutionTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(result)
+		MockMvcWebTestClient.resultActionsFor(result)
 				.andExpect(status().isOk())
 				.andExpect(model().size(1))
 				.andExpect(model().attributeExists("person"))
@@ -77,7 +77,7 @@ class ViewResolutionTests {
 	@Test
 	void jsonOnly() {
 		WebTestClient testClient =
-				MockMvcTestClient.bindToController(new PersonController())
+				MockMvcWebTestClient.bindToController(new PersonController())
 						.singleView(new MappingJackson2JsonView())
 						.build();
 
@@ -94,7 +94,7 @@ class ViewResolutionTests {
 		marshaller.setClassesToBeBound(Person.class);
 
 		WebTestClient testClient =
-				MockMvcTestClient.bindToController(new PersonController())
+				MockMvcWebTestClient.bindToController(new PersonController())
 						.singleView(new MarshallingView(marshaller))
 						.build();
 
@@ -123,7 +123,7 @@ class ViewResolutionTests {
 		cnViewResolver.afterPropertiesSet();
 
 		WebTestClient testClient =
-				MockMvcTestClient.bindToController(new PersonController())
+				MockMvcWebTestClient.bindToController(new PersonController())
 						.viewResolvers(cnViewResolver, new InternalResourceViewResolver())
 						.build();
 
@@ -133,7 +133,7 @@ class ViewResolutionTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(result)
+		MockMvcWebTestClient.resultActionsFor(result)
 				.andExpect(model().size(1))
 				.andExpect(model().attributeExists("person"))
 				.andExpect(forwardedUrl("person/show"));
@@ -155,7 +155,7 @@ class ViewResolutionTests {
 
 	@Test
 	void defaultViewResolver() throws Exception {
-		WebTestClient client = MockMvcTestClient.bindToController(new PersonController()).build();
+		WebTestClient client = MockMvcWebTestClient.bindToController(new PersonController()).build();
 
 		EntityExchangeResult result = client.get().uri("/person/Corea")
 				.exchange()
@@ -163,7 +163,7 @@ class ViewResolutionTests {
 				.expectBody().isEmpty();
 
 		// Further assertions on the server response
-		MockMvcTestClient.resultActionsFor(result)
+		MockMvcWebTestClient.resultActionsFor(result)
 				.andExpect(model().attribute("person", hasProperty("name", equalTo("Corea"))))
 				.andExpect(forwardedUrl("person/show"));  // InternalResourceViewResolver
 	}
@@ -47,7 +47,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.RequestParameterTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resulthandlers/PrintingResultHandlerSmokeTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resulthandlers/PrintingResultHandlerSmokeTests.java
index 2fda9eac8a..629ada4fa9 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resulthandlers/PrintingResultHandlerSmokeTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resulthandlers/PrintingResultHandlerSmokeTests.java
@@ -27,12 +27,12 @@ import org.junit.jupiter.api.Test;
 import org.springframework.http.MediaType;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.PostMapping;
 import org.springframework.web.bind.annotation.RestController;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resulthandlers.PrintingResultHandlerSmokeTests}.
  *
  * @author Rossen Stoyanchev
@@ -41,7 +41,7 @@ import org.springframework.web.bind.annotation.RestController;
 public class PrintingResultHandlerSmokeTests {
 
 	private final WebTestClient testClient =
-			MockMvcTestClient.bindToController(new SimpleController()).build();
+			MockMvcWebTestClient.bindToController(new SimpleController()).build();
 
 
 	// Not intended to be executed with the build.
@@ -27,12 +27,12 @@ import org.junit.jupiter.api.Test;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resulthandlers.PrintingResultHandlerSmokeTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ContentAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ContentAssertionTests.java
index 0f1480d596..fd921973bb 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ContentAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ContentAssertionTests.java
@@ -23,7 +23,7 @@ import org.junit.jupiter.api.Test;
 import org.springframework.http.MediaType;
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.bind.annotation.ResponseBody;
 
@@ -31,7 +31,7 @@ import static org.hamcrest.Matchers.containsString;
 import static org.hamcrest.Matchers.equalTo;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.ContentAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -39,7 +39,7 @@ import static org.hamcrest.Matchers.equalTo;
 public class ContentAssertionTests {
 
 	private final WebTestClient testClient =
-			MockMvcTestClient.bindToController(new SimpleController()).build();
+			MockMvcWebTestClient.bindToController(new SimpleController()).build();
 
 	@Test
 	public void testContentType() {
@@ -31,7 +31,7 @@ import static org.hamcrest.Matchers.containsString;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.ContentAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/CookieAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/CookieAssertionTests.java
index 5aa5cb2715..0d224e207d 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/CookieAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/CookieAssertionTests.java
@@ -23,7 +23,7 @@ import org.junit.jupiter.api.Test;
 
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.servlet.i18n.CookieLocaleResolver;
 import org.springframework.web.servlet.i18n.LocaleChangeInterceptor;
@@ -33,7 +33,7 @@ import static org.hamcrest.Matchers.startsWith;
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.CookieAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -51,7 +51,7 @@ public class CookieAssertionTests {
 		localeResolver.setCookieDomain("domain");
 		localeResolver.setCookieHttpOnly(true);
 
-		client = MockMvcTestClient.bindToController(new SimpleController())
+		client = MockMvcWebTestClient.bindToController(new SimpleController())
 				.interceptors(new LocaleChangeInterceptor())
 				.localeResolver(localeResolver)
 				.alwaysExpect(status().isOk())
@@ -33,7 +33,7 @@ import static org.hamcrest.Matchers.startsWith;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.CookieAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/FlashAttributeAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/FlashAttributeAssertionTests.java
index 640de972a5..95d6b21a12 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/FlashAttributeAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/FlashAttributeAssertionTests.java
@@ -24,7 +24,7 @@ import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
 import org.springframework.test.web.servlet.ResultActions;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.PostMapping;
 import org.springframework.web.servlet.mvc.support.RedirectAttributes;
 
@@ -37,7 +37,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.FlashAttributeAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -45,7 +45,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 public class FlashAttributeAssertionTests {
 
 	private final WebTestClient client =
-			MockMvcTestClient.bindToController(new PersonController())
+			MockMvcWebTestClient.bindToController(new PersonController())
 					.alwaysExpect(status().isFound())
 					.alwaysExpect(flash().attributeCount(3))
 					.build();
@@ -84,7 +84,7 @@ public class FlashAttributeAssertionTests {
 
 	private ResultActions performRequest() {
 		EntityExchangeResult result = client.post().uri("/persons").exchange().expectBody().isEmpty();
-		return MockMvcTestClient.resultActionsFor(result);
+		return MockMvcWebTestClient.resultActionsFor(result);
 	}
 
 
@@ -37,7 +37,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.FlashAttributeAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/HandlerAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/HandlerAssertionTests.java
index 61c0e41f55..8139990270 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/HandlerAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/HandlerAssertionTests.java
@@ -24,7 +24,7 @@ import org.springframework.http.ResponseEntity;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
 import org.springframework.test.web.servlet.ResultActions;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.bind.annotation.RestController;
 import org.springframework.web.servlet.mvc.method.annotation.MvcUriComponentsBuilder;
@@ -38,7 +38,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.web.servlet.mvc.method.annotation.MvcUriComponentsBuilder.on;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.HandlerAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -46,7 +46,7 @@ import static org.springframework.web.servlet.mvc.method.annotation.MvcUriCompon
 public class HandlerAssertionTests {
 
 	private final WebTestClient client =
-			MockMvcTestClient.bindToController(new SimpleController())
+			MockMvcWebTestClient.bindToController(new SimpleController())
 					.alwaysExpect(status().isOk())
 					.build();
 
@@ -90,7 +90,7 @@ public class HandlerAssertionTests {
 
 	private ResultActions performRequest() {
 		EntityExchangeResult result = client.get().uri("/").exchange().expectBody().isEmpty();
-		return MockMvcTestClient.resultActionsFor(result);
+		return MockMvcWebTestClient.resultActionsFor(result);
 	}
 
 
@@ -38,7 +38,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.HandlerAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/HeaderAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/HeaderAssertionTests.java
index 20c736b6f3..3f489fe9fa 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/HeaderAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/HeaderAssertionTests.java
@@ -30,7 +30,7 @@ import org.springframework.http.ResponseEntity;
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.PathVariable;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.context.request.WebRequest;
@@ -48,7 +48,7 @@ import static org.springframework.http.HttpHeaders.LAST_MODIFIED;
 import static org.springframework.http.HttpHeaders.VARY;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.HeaderAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -78,7 +78,7 @@ public class HeaderAssertionTests {
 
 		PersonController controller = new PersonController();
 		controller.setStubTimestamp(this.currentTime);
-		this.testClient = MockMvcTestClient.bindToController(controller).build();
+		this.testClient = MockMvcWebTestClient.bindToController(controller).build();
 	}
 
 
@@ -48,7 +48,7 @@ import static org.springframework.http.HttpHeaders.LAST_MODIFIED;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.HeaderAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/JsonPathAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/JsonPathAssertionTests.java
index 50216806c1..0bbe20a6e6 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/JsonPathAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/JsonPathAssertionTests.java
@@ -24,7 +24,7 @@ import org.springframework.http.HttpHeaders;
 import org.springframework.http.MediaType;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.util.LinkedMultiValueMap;
 import org.springframework.util.MultiValueMap;
 import org.springframework.web.bind.annotation.RequestMapping;
@@ -40,7 +40,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.JsonPathAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -48,7 +48,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 public class JsonPathAssertionTests {
 
 	private final WebTestClient client =
-			MockMvcTestClient.bindToController(new MusicController())
+			MockMvcWebTestClient.bindToController(new MusicController())
 					.alwaysExpect(status().isOk())
 					.alwaysExpect(content().contentType(MediaType.APPLICATION_JSON))
 					.configureClient()
@@ -40,7 +40,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.JsonPathAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ModelAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ModelAssertionTests.java
index 274000430c..76384b3b43 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ModelAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ModelAssertionTests.java
@@ -26,7 +26,7 @@ import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
 import org.springframework.test.web.servlet.ResultActions;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.ui.Model;
 import org.springframework.validation.BindingResult;
 import org.springframework.web.bind.annotation.ControllerAdvice;
@@ -45,7 +45,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.ModelAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -53,7 +53,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 public class ModelAssertionTests {
 
 	private final WebTestClient client =
-			MockMvcTestClient.bindToController(new SampleController("a string value", 3, new Person("a name")))
+			MockMvcWebTestClient.bindToController(new SampleController("a string value", 3, new Person("a name")))
 					.controllerAdvice(new ModelAttributeAdvice())
 					.alwaysExpect(status().isOk())
 					.build();
@@ -96,7 +96,7 @@ public class ModelAssertionTests {
 
 	private ResultActions performRequest(HttpMethod method, String uri) {
 		EntityExchangeResult result = client.method(method).uri(uri).exchange().expectBody().isEmpty();
-		return MockMvcTestClient.resultActionsFor(result);
+		return MockMvcWebTestClient.resultActionsFor(result);
 	}
 
 
@@ -45,7 +45,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.ModelAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/RequestAttributeAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/RequestAttributeAssertionTests.java
index bc48bccdf7..492c39c2ee 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/RequestAttributeAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/RequestAttributeAssertionTests.java
@@ -23,7 +23,7 @@ import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
 import org.springframework.test.web.servlet.ResultActions;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.GetMapping;
 import org.springframework.web.servlet.HandlerMapping;
 
@@ -34,7 +34,7 @@ import static org.springframework.test.web.servlet.request.MockMvcRequestBuilder
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.request;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.RequestAttributeAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -42,12 +42,12 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 public class RequestAttributeAssertionTests {
 
 	private final WebTestClient mainServletClient =
-			MockMvcTestClient.bindToController(new SimpleController())
+			MockMvcWebTestClient.bindToController(new SimpleController())
 					.defaultRequest(get("/").servletPath("/main"))
 					.build();
 
 	private final WebTestClient client =
-			MockMvcTestClient.bindToController(new SimpleController()).build();
+			MockMvcWebTestClient.bindToController(new SimpleController()).build();
 
 
 	@Test
@@ -76,7 +76,7 @@ public class RequestAttributeAssertionTests {
 				.expectStatus().isOk()
 				.expectBody().isEmpty();
 
-		return MockMvcTestClient.resultActionsFor(result);
+		return MockMvcWebTestClient.resultActionsFor(result);
 	}
 
 
@@ -34,7 +34,7 @@ import static org.springframework.test.web.servlet.request.MockMvcRequestBuilder
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * MockMvcWebTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.RequestAttributeAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/SessionAttributeAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/SessionAttributeAssertionTests.java
index 5b1add31ff..1f325f79ac 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/SessionAttributeAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/SessionAttributeAssertionTests.java
@@ -24,7 +24,7 @@ import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
 import org.springframework.test.web.servlet.ResultActions;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.ui.Model;
 import org.springframework.web.bind.annotation.ModelAttribute;
 import org.springframework.web.bind.annotation.RequestMapping;
@@ -39,7 +39,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.SessionAttributeAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -47,7 +47,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 public class SessionAttributeAssertionTests {
 
 	private final WebTestClient client =
-			MockMvcTestClient.bindToController(new SimpleController())
+			MockMvcWebTestClient.bindToController(new SimpleController())
 					.alwaysExpect(status().isOk())
 					.build();
 
@@ -84,7 +84,7 @@ public class SessionAttributeAssertionTests {
 
 	private ResultActions performRequest() {
 		EntityExchangeResult result = client.post().uri("/").exchange().expectBody().isEmpty();
-		return MockMvcTestClient.resultActionsFor(result);
+		return MockMvcWebTestClient.resultActionsFor(result);
 	}
 
 
@@ -39,7 +39,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.SessionAttributeAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/StatusAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/StatusAssertionTests.java
index 80759c5fcb..a2c7fc39f4 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/StatusAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/StatusAssertionTests.java
@@ -25,7 +25,7 @@ import org.springframework.core.annotation.AliasFor;
 import org.springframework.http.HttpStatus;
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.bind.annotation.ResponseBody;
 import org.springframework.web.bind.annotation.ResponseStatus;
@@ -37,7 +37,7 @@ import static org.springframework.http.HttpStatus.INTERNAL_SERVER_ERROR;
 import static org.springframework.http.HttpStatus.NOT_IMPLEMENTED;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.StatusAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -45,7 +45,7 @@ import static org.springframework.http.HttpStatus.NOT_IMPLEMENTED;
 public class StatusAssertionTests {
 
 	private final WebTestClient testClient =
-			MockMvcTestClient.bindToController(new StatusController()).build();
+			MockMvcWebTestClient.bindToController(new StatusController()).build();
 
 
 	@Test
@@ -37,7 +37,7 @@ import static org.springframework.http.HttpStatus.INTERNAL_SERVER_ERROR;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.StatusAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/UrlAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/UrlAssertionTests.java
index 15f8bb19bf..2beec1c5b6 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/UrlAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/UrlAssertionTests.java
@@ -21,14 +21,14 @@ import org.junit.jupiter.api.Test;
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.RequestMapping;
 
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.forwardedUrlPattern;
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.redirectedUrlPattern;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.UrlAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -36,7 +36,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 public class UrlAssertionTests {
 
 	private final WebTestClient testClient =
-			MockMvcTestClient.bindToController(new SimpleController()).build();
+			MockMvcWebTestClient.bindToController(new SimpleController()).build();
 
 
 	@Test
@@ -52,7 +52,7 @@ public class UrlAssertionTests {
 		EntityExchangeResult result =
 				testClient.get().uri("/persons").exchange().expectBody().isEmpty();
 
-		MockMvcTestClient.resultActionsFor(result)
+		MockMvcWebTestClient.resultActionsFor(result)
 				.andExpect(redirectedUrlPattern("/persons/*"));
 	}
 
@@ -69,7 +69,7 @@ public class UrlAssertionTests {
 		EntityExchangeResult result =
 				testClient.get().uri("/").exchange().expectBody().isEmpty();
 
-		MockMvcTestClient.resultActionsFor(result)
+		MockMvcWebTestClient.resultActionsFor(result)
 				.andExpect(forwardedUrlPattern("/ho?e"));
 	}
 
@@ -21,14 +21,14 @@ import org.junit.jupiter.api.Test;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.UrlAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ViewNameAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ViewNameAssertionTests.java
index b60196e01d..645967c48c 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ViewNameAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/ViewNameAssertionTests.java
@@ -21,7 +21,7 @@ import org.junit.jupiter.api.Test;
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.reactive.server.EntityExchangeResult;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.RequestMapping;
 
 import static org.hamcrest.Matchers.containsString;
@@ -30,7 +30,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.view;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.UrlAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -38,21 +38,21 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 public class ViewNameAssertionTests {
 
 	private final WebTestClient client =
-			MockMvcTestClient.bindToController(new SimpleController())
+			MockMvcWebTestClient.bindToController(new SimpleController())
 					.alwaysExpect(status().isOk())
 					.build();
 
 
 	@Test
 	public void testEqualTo() throws Exception {
-		MockMvcTestClient.resultActionsFor(performRequest())
+		MockMvcWebTestClient.resultActionsFor(performRequest())
 			.andExpect(view().name("mySpecialView"))
 			.andExpect(view().name(equalTo("mySpecialView")));
 	}
 
 	@Test
 	public void testHamcrestMatcher() throws Exception {
-		MockMvcTestClient.resultActionsFor(performRequest())
+		MockMvcWebTestClient.resultActionsFor(performRequest())
 				.andExpect(view().name(containsString("Special")));
 	}
 
@@ -30,7 +30,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.UrlAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/XmlContentAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/XmlContentAssertionTests.java
index 2666021124..a608459937 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/XmlContentAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/XmlContentAssertionTests.java
@@ -32,7 +32,7 @@ import org.springframework.http.MediaType;
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.bind.annotation.ResponseBody;
 
@@ -40,7 +40,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.XmlContentAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -58,7 +58,7 @@ public class XmlContentAssertionTests {
 
 
 	private final WebTestClient testClient =
-			MockMvcTestClient.bindToController(new MusicController())
+			MockMvcWebTestClient.bindToController(new MusicController())
 					.alwaysExpect(status().isOk())
 					.alwaysExpect(content().contentType(MediaType.parseMediaType("application/xml;charset=UTF-8")))
 					.configureClient()
@@ -40,7 +40,7 @@ import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.XmlContentAssertionTests}.
  *
diff --git a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/XpathAssertionTests.java b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/XpathAssertionTests.java
index c7fd97f6a1..b464c42249 100644
--- a/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/XpathAssertionTests.java
+++ b/spring-test/src/test/java/org/springframework/test/web/servlet/samples/client/standalone/resultmatches/XpathAssertionTests.java
@@ -34,7 +34,7 @@ import org.springframework.http.MediaType;
 import org.springframework.stereotype.Controller;
 import org.springframework.test.web.Person;
 import org.springframework.test.web.reactive.server.WebTestClient;
-import org.springframework.test.web.servlet.client.MockMvcTestClient;
+import org.springframework.test.web.servlet.client.MockMvcWebTestClient;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.bind.annotation.ResponseBody;
 
@@ -48,7 +48,7 @@ import static org.springframework.web.bind.annotation.RequestMethod.GET;
 import static org.springframework.web.bind.annotation.RequestMethod.HEAD;
 
 /**
  * MockMvcTestClient equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.XpathAssertionTests}.
  *
  * @author Rossen Stoyanchev
@@ -59,7 +59,7 @@ public class XpathAssertionTests {
 			Collections.singletonMap("ns", "https://example.org/music/people");
 
 	private final WebTestClient testClient =
-			MockMvcTestClient.bindToController(new MusicController())
+			MockMvcWebTestClient.bindToController(new MusicController())
 					.alwaysExpect(status().isOk())
 					.alwaysExpect(content().contentType(MediaType.parseMediaType("application/xml;charset=UTF-8")))
 					.configureClient()
@@ -157,7 +157,7 @@ public class XpathAssertionTests {
 
 	@Test
 	public void testFeedWithLinefeedChars() {
-		MockMvcTestClient.bindToController(new BlogFeedController()).build()
+		MockMvcWebTestClient.bindToController(new BlogFeedController()).build()
 				.get().uri("/blog.atom")
 				.accept(MediaType.APPLICATION_ATOM_XML)
 				.exchange()
@@ -48,7 +48,7 @@ import static org.springframework.web.bind.annotation.RequestMethod.GET;
 
 /**
- * MockMvcTestClient equivalent of the MockMvc
+ * {@link MockMvcWebTestClient} equivalent of the MockMvc
  * {@link org.springframework.test.web.servlet.samples.standalone.resultmatchers.XpathAssertionTests}.
  *